@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Linker::XCOFF;
-$ExtUtils::Builder::Linker::XCOFF::VERSION = '0.001';
+$ExtUtils::Builder::Linker::XCOFF::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -47,11 +47,11 @@ ExtUtils::Builder::Linker::XCOFF
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
