@@ -1,5 +1,5 @@
 package ExtUtils::Builder::MultiLingual;
-$ExtUtils::Builder::MultiLingual::VERSION = '0.001';
+$ExtUtils::Builder::MultiLingual::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -30,11 +30,11 @@ ExtUtils::Builder::MultiLingual
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
