@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Profile::Perl;
-$ExtUtils::Builder::Profile::Perl::VERSION = '0.001';
+$ExtUtils::Builder::Profile::Perl::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -74,11 +74,11 @@ ExtUtils::Builder::Profile::Perl
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
